{ config, pkgs, inputs, lib, nixpkgs-nixos-unstable-and-unfree, ... }: {
  networking.hostName = "foryog";

  imports = [
    ./hardware-configuration.nix
    ../../backups.nix
    ../../boot.nix
    ../../git
    ../../gnome
    ../../gui
    ../../libvirt.nix
    ../../mercurial
    ../../vim
    ../../sdr.nix
  ];

  fileSystems."/" = { options = [ "compress=zstd" ]; };

  boot.kernelParams =
    [ "initcall_debug" ''dyndbg="file suspend.c +p"'' "no_console_suspend" ];
  boot.cleanTmpDir = true;
  boot.binfmt.emulatedSystems = [ "aarch64-linux" ];
  boot.plymouth = {
    enable = true;
    logo = ./boot.png;
  };

  zramSwap = {
    enable = true;
    algorithm = "zstd";
    memoryPercent = 75;
  };

  time.timeZone = "Europe/London";

  hardware.trackpoint.enable = true;

  services.xserver = {
    libinput = {
      enable = true;
      touchpad = {
        tapping = true;
        naturalScrolling = false;
        middleEmulation = false;
        disableWhileTyping = true;
      };
    };
  };
  services.fprintd = { enable = true; };
  programs.ccache.enable = true;
  hardware.opengl.extraPackages = with pkgs; [ libva ];
  programs.steam.enable = true;
  nixpkgs.config.allowUnfreePredicate = pkg:
    builtins.elem (lib.getName pkg) [
      "steam"
      "steam-original"
      "steam-runtime"
      "steam-run"
      "vscode-with-extensions"
      "vscode"
    ];

  home-manager.users.cyryl = { ... }: {
    imports =
      [ ../../home-manager/programs/alacritty.nix ../../gui/vscode.nix ];
    home.packages =
      with inputs.nixpkgs-nixos-unstable.legacyPackages."x86_64-linux";
      [ bisq-desktop ] ++

      (with pkgs; [ lutris ])
      ++ (with inputs.endless-sky.legacyPackages."x86_64-linux";
        [ endless-sky ]);
  };
}
